<?php

namespace Drupal\preview_graphql\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Link;
use Drupal\Core\Url;

/**
 * Class SettingsForm.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'preview_graphql.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('preview_graphql.settings');
    $form = parent::buildForm($form, $form_state);

    $form['url_front'] = [
      '#type' => 'url',
      '#default_value' => $config->get('url_front'),
      '#required' => TRUE,
      '#title' => $this->t('Front url'),
    ];
    $form['uri_front'] = [
      '#type' => 'textfield',
      '#default_value' => $config->get('uri_front'),
      '#required' => TRUE,
      '#title' => $this->t('Front path'),
    ];
    $link = Link::fromTextAndUrl(t('documentation'), Url::fromUri('https://www.drupal.org/docs/8/modules/preview-graphql'));
    $form['query_gql'] = [
      '#type' => 'textarea',
      '#default_value' => $config->get('query_gql'),
      '#required' => TRUE,
      '#rows' => 25,
      '#title' => $this->t('Default query graphql'),
      '#description' => $this->t('Put here the content of your query as you call the endpoint to get your data. Do not include the first parent field, only the content.For more information see @doc', ['@doc' => $link]),
    ];
    $form['fragment_gql'] = [
      '#type' => 'textarea',
      '#rows' => 50,
      '#default_value' => $config->get('fragment_gql'),
      '#required' => TRUE,
      '#title' => $this->t('Default fragment graphql'),
      '#description' => $this->t('Put here the same query as you call the endpoint to get your data.'),
    ];
    $entity_type = $config->get('entity_type');
    if (!empty($entity_type)) {
      $form['entity_type'] = [
        '#markup' => t('Entity type currently config : %entity_type', ['%entity_type' => implode(',', $entity_type)]),
      ];
    }

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    $this->config('preview_graphql.settings')
      ->set('url_front', $form_state->getValue('url_front'))
      ->set('uri_front', $form_state->getValue('uri_front'))
      ->set('query_gql', $form_state->getValue('query_gql'))
      ->set('fragment_gql', $form_state->getValue('fragment_gql'))
      ->save();
  }

}
