<?php

namespace Drupal\preview_graphql\Plugin\GraphQL\Fields;

use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\graphql\GraphQL\Execution\ResolveContext;
use Drupal\graphql\Plugin\GraphQL\Fields\FieldPluginBase;
use Drupal\preview_graphql\Services\PreviewGraphQLManager;
use GraphQL\Error\Error;
use Symfony\Component\DependencyInjection\ContainerInterface;
use GraphQL\Type\Definition\ResolveInfo;

/**
 * @GraphQLField(
 *   id = "preview_graphql_field",
 *   secure = true,
 *   name = "previewGraphQLField",
 *   type = "any!",
 *   response_cache_contexts = {"headers:Authorization"}
 * )
 */
class PreviewGraphQLField extends FieldPluginBase implements ContainerFactoryPluginInterface {


  /**
   * A preview graphql manager service.
   *
   * @var \Drupal\preview_graphql\Services\PreviewGraphQLManager
   */
  protected $previewGraphQLManager;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $pluginId, $pluginDefinition) {
    return new static(
      $configuration,
      $pluginId,
      $pluginDefinition,
      $container->get('preview_graphql.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration, $pluginId, $pluginDefinition, PreviewGraphQLManager $preview_graphql_manager) {
    parent::__construct($configuration, $pluginId, $pluginDefinition);
    $this->previewGraphQLManager = $preview_graphql_manager;

  }

  /**
   * {@inheritdoc}
   */
  public function resolveValues($value, array $args, ResolveContext $context, ResolveInfo $info) {
    $context->addCacheContexts(['headers:Authorization']);
    $result = $this->previewGraphQLManager->getCacheDataValueByJwt('gql');
    if (is_array($result) && !empty($result['error'])) {
      throw new Error(sprintf('%s', $result['error']));
    }
    yield $result;
  }

}
